summary refs log tree commit diff
path: root/sysdeps/unix
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix')
-rw-r--r--sysdeps/unix/sysv/linux/Dist2
-rw-r--r--sysdeps/unix/sysv/linux/Makefile2
-rw-r--r--sysdeps/unix/sysv/linux/__recvmsg.S5
-rw-r--r--sysdeps/unix/sysv/linux/__sendmsg.S5
-rw-r--r--sysdeps/unix/sysv/linux/bits/socket.h23
-rw-r--r--sysdeps/unix/sysv/linux/recvmsg.S4
-rw-r--r--sysdeps/unix/sysv/linux/recvmsg.c74
-rw-r--r--sysdeps/unix/sysv/linux/sendmsg.S4
-rw-r--r--sysdeps/unix/sysv/linux/sendmsg.c124
9 files changed, 16 insertions, 227 deletions
diff --git a/sysdeps/unix/sysv/linux/Dist b/sysdeps/unix/sysv/linux/Dist
index e813a08c14..dbe401de3f 100644
--- a/sysdeps/unix/sysv/linux/Dist
+++ b/sysdeps/unix/sysv/linux/Dist
@@ -75,7 +75,5 @@ sys/user.h
 sys/vt.h
 xstatconv.c
 getdents64.c
-__sendmsg.S
-__recvmsg.S
 getresuid.c
 getresgid.c
diff --git a/sysdeps/unix/sysv/linux/Makefile b/sysdeps/unix/sysv/linux/Makefile
index af53184cb2..b84fbed0c7 100644
--- a/sysdeps/unix/sysv/linux/Makefile
+++ b/sysdeps/unix/sysv/linux/Makefile
@@ -58,7 +58,7 @@ ifeq ($(subdir),socket)
 sysdep_headers += net/if.h net/if_ppp.h net/ppp-comp.h \
 		  net/ppp_defs.h net/if_arp.h net/route.h net/ethernet.h \
 		  net/if_slip.h net/if_packet.h
-sysdep_routines += cmsg_nxthdr sa_len __sendmsg __recvmsg
+sysdep_routines += cmsg_nxthdr sa_len
 endif
 
 ifeq ($(subdir),sunrpc)
diff --git a/sysdeps/unix/sysv/linux/__recvmsg.S b/sysdeps/unix/sysv/linux/__recvmsg.S
deleted file mode 100644
index f76cce0913..0000000000
--- a/sysdeps/unix/sysv/linux/__recvmsg.S
+++ /dev/null
@@ -1,5 +0,0 @@
-#define	socket	___syscall_recvmsg
-#define	__socket __syscall_recvmsg
-#define SOCKOP____syscall_recvmsg SOCKOP_recvmsg
-#define	NARGS	3
-#include <socket.S>
diff --git a/sysdeps/unix/sysv/linux/__sendmsg.S b/sysdeps/unix/sysv/linux/__sendmsg.S
deleted file mode 100644
index bd935bd7a9..0000000000
--- a/sysdeps/unix/sysv/linux/__sendmsg.S
+++ /dev/null
@@ -1,5 +0,0 @@
-#define	socket	___syscall_sendmsg
-#define	__socket __syscall_sendmsg
-#define SOCKOP____syscall_sendmsg SOCKOP_sendmsg
-#define	NARGS	3
-#include <socket.S>
diff --git a/sysdeps/unix/sysv/linux/recvmsg.S b/sysdeps/unix/sysv/linux/recvmsg.S
new file mode 100644
index 0000000000..b4125d2caa
--- /dev/null
+++ b/sysdeps/unix/sysv/linux/recvmsg.S
@@ -0,0 +1,4 @@
+#define	socket	recvmsg
+#define	__socket __libc_recvmsg
+#define	NARGS	3
+#include <socket.S>
diff --git a/sysdeps/unix/sysv/linux/recvmsg.c b/sysdeps/unix/sysv/linux/recvmsg.c
deleted file mode 100644
index 52a0abcf67..0000000000
--- a/sysdeps/unix/sysv/linux/recvmsg.c
+++ /dev/null
@@ -1,74 +0,0 @@
-/* Copyright (C) 1998 Free Software Foundation, Inc.
-   This file is part of the GNU C Library.
-
-   The GNU C Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
-
-   The GNU C Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
-
-#include <sys/socket.h>
-#include <errno.h>
-#include <string.h>
-
-#include <asm/posix_types.h>
-
-/* The kernel expects this structure in SCM_CREDS messages.
- * Note: sizeof(struct __kernel_ucred) <= sizeof(struct cmsgcred) must hold.
- */
-struct __kernel_ucred
-{
-  __kernel_pid_t pid;
-  __kernel_uid_t uid;
-  __kernel_gid_t gid;
-};
-
-extern int __syscall_recvmsg (int, struct msghdr *, int);
-
-int
-__libc_recvmsg (int fd, struct msghdr *message, int flags)
-{
-  struct cmsghdr *cm;
-  int ret;
-
-  ret = __syscall_recvmsg (fd, message, flags);
-
-  if (ret == -1)
-    return ret;
-
-  /* Postprocess the message control block for SCM_CREDS.  */
-  cm = CMSG_FIRSTHDR (message);
-  while (cm)
-    {
-      if (cm->cmsg_type == SCM_CREDS)
- 	{
-	  struct cmsgcred *c = (struct cmsgcred *) CMSG_DATA (cm);
-	  struct __kernel_ucred u;
-	  int i;
-	  memcpy (&u, CMSG_DATA (cm), sizeof (struct __kernel_ucred));
-
-	  c->cmcred_pid = u.pid;
-	  c->cmcred_uid = u.uid;
-	  c->cmcred_gid = u.gid;
-
-	  c->cmcred_euid = -1;
-	  c->cmcred_ngroups = 0;
-	  for (i = 0; i < CMGROUP_MAX; i++)
-	    c->cmcred_groups[i] = -1;
-	}
-      cm = CMSG_NXTHDR (message, cm);
-    }
-
-  return ret;
-}
-
-weak_alias (__libc_recvmsg, recvmsg)
diff --git a/sysdeps/unix/sysv/linux/sendmsg.S b/sysdeps/unix/sysv/linux/sendmsg.S
new file mode 100644
index 0000000000..0defce9f9e
--- /dev/null
+++ b/sysdeps/unix/sysv/linux/sendmsg.S
@@ -0,0 +1,4 @@
+#define	socket	sendmsg
+#define	__socket __libc_sendmsg
+#define	NARGS	3
+#include <socket.S>
diff --git a/sysdeps/unix/sysv/linux/sendmsg.c b/sysdeps/unix/sysv/linux/sendmsg.c
deleted file mode 100644
index 304aa6e2a1..0000000000
--- a/sysdeps/unix/sysv/linux/sendmsg.c
+++ /dev/null
@@ -1,124 +0,0 @@
-/* Copyright (C) 1998 Free Software Foundation, Inc.
-   This file is part of the GNU C Library.
-
-   The GNU C Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
-
-   The GNU C Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
-
-#include <sys/socket.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-
-#include <asm/posix_types.h>
-
-/* The kernel expects this structure in SCM_CREDS messages.
- * Note: sizeof(struct __kernel_ucred) <= sizeof(struct cmsgcred) must hold.
- */
-struct kernel_ucred
-  {
-    __kernel_pid_t pid;
-    __kernel_uid_t uid;
-    __kernel_gid_t gid;
-  };
-
-struct credmsg
-  {
-    struct cmsghdr cm;
-    struct cmsgcred cc;
-  };
-
-struct kcredmsg
-  {
-    struct cmsghdr cm;
-    struct kernel_ucred cc;
-  };
-
-extern int __syscall_sendmsg (int, const struct msghdr *, int);
-
-/* Send a message described by MESSAGE on socket FD.
-   Returns the number of bytes sent, or -1 for errors.  */
-int
-__libc_sendmsg (int fd, const struct msghdr *message, int flags)
-{
-  struct msghdr m;
-  char *buf, *a, *b;
-  struct credmsg *cred = 0;
-  struct kcredmsg *kcred;
-  struct cmsghdr *cm;
-  long int offset = 0;
-  pid_t pid;
-
-  /* Preprocess the message control block for SCM_CREDS. */
-  if (message->msg_controllen)
-    {
-      cm = CMSG_FIRSTHDR (message);
-      while (cm)
-	{
-	  if (cm->cmsg_type == SCM_CREDS)
-	    {
-	      if (cred ||
-		  cm->cmsg_len < CMSG_LEN (sizeof (struct cmsgcred)))
-		{
-		  __set_errno (EINVAL);
-		  return -1;
-		}
-	      else
-		{
-		  cred = (struct credmsg *) cm;
-		  offset = (char *) cm - (char *) message->msg_control;
-		}
-	    }
-	  cm = CMSG_NXTHDR ((struct msghdr *) message, cm);
-	}
-
-      if (cred)
-	{
-	  buf = alloca (message->msg_controllen);
-	  memcpy (buf, message->msg_control, message->msg_controllen);
-	  kcred = (struct kcredmsg *) (buf + offset);
-	  a = (char *) kcred + CMSG_LEN (sizeof (struct kernel_ucred));
-	  b = (char *) kcred + CMSG_LEN (sizeof (struct cmsgcred));
-	  memmove (a, b, message->msg_controllen - (b - buf));
-
-	  kcred->cm.cmsg_len = CMSG_LEN (sizeof (struct kernel_ucred));
-
-	  /* Linux expects the calling process to pass in
-	     its credentials, and sanity checks them.
-	     You can send real, effective, or set- uid and gid.
-	     If the user hasn't filled in the buffer, we default to
-	     real uid and gid. */
-	  pid = __getpid ();
-	  if (cred->cc.cmcred_pid != pid)
-	    {
-	      kcred->cc.pid = pid;
-	      kcred->cc.uid = __getuid ();
-	      kcred->cc.gid = __getgid ();
-	    }
-	  else
-	    {
-	      kcred->cc.uid = cred->cc.cmcred_uid;
-	      kcred->cc.gid = cred->cc.cmcred_gid;
-	    }
-	  memcpy (&m, message, sizeof (struct msghdr));
-	  m.msg_control = buf;
-	  m.msg_controllen -= b - a;
-	  return __syscall_sendmsg (fd, &m, flags);
-	}
-    }
-  return __syscall_sendmsg (fd, message, flags);
-}
-
-weak_alias (__libc_sendmsg, sendmsg)
diff --git a/sysdeps/unix/sysv/linux/bits/socket.h b/sysdeps/unix/sysv/linux/bits/socket.h
index c1f752ec29..226e332043 100644
--- a/sysdeps/unix/sysv/linux/bits/socket.h
+++ b/sysdeps/unix/sysv/linux/bits/socket.h
@@ -225,29 +225,20 @@ enum
     SCM_RIGHTS = 0x01,		/* Transfer file descriptors.  */
 #define SCM_RIGHTS SCM_RIGHTS
 #ifdef __USE_BSD
-    SCM_CREDS = 0x02,		/* BSD-compatible credentials passing.  */
-# define SCM_CREDS SCM_CREDS
+    SCM_CREDENTIALS = 0x02,     /* Credentials passing.  */
+# define SCM_CREDENTIALS SCM_CREDENTIALS
 #endif
     __SCM_CONNECT = 0x03,	/* Data array is `struct scm_connect'.  */
   };
 
-#ifdef __USE_BSD
-
-/* User visible structure for SCM_CREDS message
-   (chosen for BSD source compatibility) */
+/* User visible structure for SCM_CREDENTIALS message */
 
-# define CMGROUP_MAX 16  /* Linux does not provide this info, so it doesn't
-			    matter... use what bsd does. */
-struct cmsgcred
+struct ucred
 {
-  pid_t cmcred_pid;			/* PID of sending process.  */
-  uid_t cmcred_uid;			/* Real UID of sending process.  */
-  uid_t cmcred_euid;			/* Effective UID of sending process. */
-  gid_t cmcred_gid;			/* Real GID of sending process.  */
-  short int cmcred_ngroups;		/* Number or groups.  */
-  gid_t cmcred_groups[CMGROUP_MAX];	/* Groups.  */
+  pid_t pid;			/* PID of sending process.  */
+  uid_t uid;			/* UID of sending process.  */
+  gid_t gid;			/* GID of sending process.  */
 };
-#endif
 
 /* Get socket manipulation related informations from kernel headers.  */
 #include <asm/socket.h>